==> ovirt-engine-3.2.0.tar.gz: frontend/webadmin/modules/userportal-gwtp/src/main/java/org/ovirt/engine/ui/userportal/ApplicationResourcesWithLookup.java <==
package org.ovirt.engine.ui.userportal;

import com.google.gwt.resources.client.ClientBundleWithLookup;
import com.google.gwt.resources.client.ImageResource;

public interface ApplicationResourcesWithLookup extends ClientBundleWithLookup {

    // OS large types
    @Source("images/os/large/Other.png")
    ImageResource otherOsLargeImage();

    @Source("images/os/large/OtherLinux.png")
    ImageResource OtherLinuxLargeImage();

    @Source("images/os/large/RHEL3.png")
    ImageResource RHEL3LargeImage();

    @Source("images/os/large/RHEL3x64.png")
    ImageResource RHEL3x64LargeImage();

    @Source("images/os/large/RHEL4.png")
    ImageResource RHEL4LargeImage();

    @Source("images/os/large/RHEL4x64.png")
    ImageResource RHEL4x64LargeImage();

    @Source("images/os/large/RHEL5.png")
    ImageResource RHEL5LargeImage();

    @Source("images/os/large/RHEL5x64.png")
    ImageResource RHEL5x64LargeImage();

    @Source("images/os/large/RHEL6.png")
    ImageResource RHEL6LargeImage();

    @Source("images/os/large/RHEL6x64.png")
    ImageResource RHEL6x64LargeImage();

    @Source("images/os/large/Unassigned.png")
    ImageResource UnassignedLargeImage();

    @Source("images/os/large/Windows2003.png")
    ImageResource Windows2003LargeImage();

    @Source("images/os/large/Windows2003x64.png")
    ImageResource Windows2003x64LargeImage();

    @Source("images/os/large/Windows2008.png")
    ImageResource Windows2008LargeImage();

    @Source("images/os/large/Windows2008R2x64.png")
    ImageResource Windows2008R2x64LargeImage();

    @Source("images/os/large/Windows2008x64.png")
    ImageResource Windows2008x64LargeImage();

    @Source("images/os/large/Windows7.png")
    ImageResource Windows7LargeImage();

    @Source("images/os/large/Windows7x64.png")
    ImageResource Windows7x64LargeImage();

    @Source("images/os/large/WindowsXP.png")
    ImageResource WindowsXPLargeImage();

    // OS type small images

    // TODO remove the same resources from ApplicationResources and rename this
    @Source("images/os/Other.jpg")
    ImageResource OtherOsSmallImage();

    @Source("images/os/OtherLinux.jpg")
    ImageResource OtherLinuxSmallImage();

    @Source("images/os/RHEL3.jpg")
    ImageResource RHEL3SmallImage();

    @Source("images/os/RHEL3x64.jpg")
    ImageResource RHEL3x64SmallImage();

    @Source("images/os/RHEL4.jpg")
    ImageResource RHEL4SmallImage();

    @Source("images/os/RHEL4x64.jpg")
    ImageResource RHEL4x64SmallImage();

    @Source("images/os/RHEL5.jpg")
    ImageResource RHEL5SmallImage();

    @Source("images/os/RHEL5x64.jpg")
    ImageResource RHEL5x64SmallImage();

    @Source("images/os/RHEL6.jpg")
    ImageResource RHEL6SmallImage();

    @Source("images/os/RHEL6x64.jpg")
    ImageResource RHEL6x64SmallImage();

    @Source("images/os/Unassigned.jpg")
    ImageResource UnassignedSmallImage();

    @Source("images/os/Windows2003.jpg")
    ImageResource Windows2003SmallImage();

    @Source("images/os/Windows2003x64.jpg")
    ImageResource Windows2003x64SmallImage();

    @Source("images/os/Windows2008.jpg")
    ImageResource Windows2008SmallImage();

    @Source("images/os/Windows2008R2x64.jpg")
    ImageResource Windows2008R2x64SmallImage();

    @Source("images/os/Windows2008x64.jpg")
    ImageResource Windows2008x64SmallImage();

    @Source("images/os/Windows7.jpg")
    ImageResource Windows7SmallImage();

    @Source("images/os/Windows7x64.jpg")
    ImageResource Windows7x64SmallImage();

    @Source("images/os/WindowsXP.jpg")
    ImageResource WindowsXPSmallImage();

    @Source("images/vmtypes/desktop_vm_icon.png")
    ImageResource desktopVmIcon();

    @Source("images/vmtypes/pool_icon.png")
    ImageResource poolVmIcon();

    @Source("images/vmtypes/server_vm_icon.png")
    ImageResource serverVmIcon();

}

==> ovirt-engine-3.2.3.tar.gz: frontend/webadmin/modules/userportal-gwtp/src/main/java/org/ovirt/engine/ui/userportal/ApplicationResourcesWithLookup.java <==
package org.ovirt.engine.ui.userportal;

import com.google.gwt.resources.client.ClientBundleWithLookup;
import com.google.gwt.resources.client.ImageResource;

public interface ApplicationResourcesWithLookup extends ClientBundleWithLookup {

    // OS large types
    @Source("images/os/large/Other.png")
    ImageResource OtherOsLargeImage();

    @Source("images/os/large/OtherLinux.png")
    ImageResource OtherLinuxLargeImage();

    @Source("images/os/large/RHEL3.png")
    ImageResource RHEL3LargeImage();

    @Source("images/os/large/RHEL3x64.png")
    ImageResource RHEL3x64LargeImage();

    @Source("images/os/large/RHEL4.png")
    ImageResource RHEL4LargeImage();

    @Source("images/os/large/RHEL4x64.png")
    ImageResource RHEL4x64LargeImage();

    @Source("images/os/large/RHEL5.png")
    ImageResource RHEL5LargeImage();

    @Source("images/os/large/RHEL5x64.png")
    ImageResource RHEL5x64LargeImage();

    @Source("images/os/large/RHEL6.png")
    ImageResource RHEL6LargeImage();

    @Source("images/os/large/RHEL6x64.png")
    ImageResource RHEL6x64LargeImage();

    @Source("images/os/large/Unassigned.png")
    ImageResource UnassignedLargeImage();

    @Source("images/os/large/Windows2003.png")
    ImageResource Windows2003LargeImage();

    @Source("images/os/large/Windows2003x64.png")
    ImageResource Windows2003x64LargeImage();

    @Source("images/os/large/Windows2008.png")
    ImageResource Windows2008LargeImage();

    @Source("images/os/large/Windows2008R2x64.png")
    ImageResource Windows2008R2x64LargeImage();

    @Source("images/os/large/Windows2008x64.png")
    ImageResource Windows2008x64LargeImage();

    @Source("images/os/large/Windows7.png")
    ImageResource Windows7LargeImage();

    @Source("images/os/large/Windows7x64.png")
    ImageResource Windows7x64LargeImage();

    @Source("images/os/large/WindowsXP.png")
    ImageResource WindowsXPLargeImage();

    // OS type small images

    // TODO remove the same resources from ApplicationResources and rename this
    @Source("images/os/Other.jpg")
    ImageResource OtherOsSmallImage();

    @Source("images/os/OtherLinux.jpg")
    ImageResource OtherLinuxSmallImage();

    @Source("images/os/RHEL3.jpg")
    ImageResource RHEL3SmallImage();

    @Source("images/os/RHEL3x64.jpg")
    ImageResource RHEL3x64SmallImage();

    @Source("images/os/RHEL4.jpg")
    ImageResource RHEL4SmallImage();

    @Source("images/os/RHEL4x64.jpg")
    ImageResource RHEL4x64SmallImage();

    @Source("images/os/RHEL5.jpg")
    ImageResource RHEL5SmallImage();

    @Source("images/os/RHEL5x64.jpg")
    ImageResource RHEL5x64SmallImage();

    @Source("images/os/RHEL6.jpg")
    ImageResource RHEL6SmallImage();

    @Source("images/os/RHEL6x64.jpg")
    ImageResource RHEL6x64SmallImage();

    @Source("images/os/Unassigned.jpg")
    ImageResource UnassignedSmallImage();

    @Source("images/os/Windows2003.jpg")
    ImageResource Windows2003SmallImage();

    @Source("images/os/Windows2003x64.jpg")
    ImageResource Windows2003x64SmallImage();

    @Source("images/os/Windows2008.jpg")
    ImageResource Windows2008SmallImage();

    @Source("images/os/Windows2008R2x64.jpg")
    ImageResource Windows2008R2x64SmallImage();

    @Source("images/os/Windows2008x64.jpg")
    ImageResource Windows2008x64SmallImage();

    @Source("images/os/Windows7.jpg")
    ImageResource Windows7SmallImage();

    @Source("images/os/Windows7x64.jpg")
    ImageResource Windows7x64SmallImage();

    @Source("images/os/WindowsXP.jpg")
    ImageResource WindowsXPSmallImage();

    @Source("images/vmtypes/desktop_vm_icon.png")
    ImageResource desktopVmIcon();

    @Source("images/vmtypes/pool_icon.png")
    ImageResource poolVmIcon();

    @Source("images/vmtypes/server_vm_icon.png")
    ImageResource serverVmIcon();

}
